@@ -23,6 +23,9 @@ from freshdesk.v2.models import (
     Ticket,
     TicketField,
     TimeEntry,
+    SolutionCategory,
+    SolutionFolder,
+    SolutionArticle,
 )
 
 
@@ -438,18 +441,28 @@ class TimeEntryAPI(object):
     def __init__(self, api):
         self._api = api
 
-    def list_time_entries(self, ticket_id=None):
-        url = "tickets/time_entries"
-        if ticket_id is not None:
-            url = "tickets/%d/time_entries" % ticket_id
-        time_entries = []
-        for r in self._api._get(url):
-            time_entries.append(TimeEntry(**r))
-        return time_entries
+    def list_time_entries(self, ticket_id=None, **kwargs):
+        url = "time_entries?"
 
-    def get_role(self, role_id):
-        url = "roles/%s" % role_id
-        return Role(**self._api._get(url))
+        if ticket_id is not None:
+            url = "tickets/%d/time_entries?" % ticket_id
+
+        page = kwargs.get("page", 1)
+        per_page = kwargs.get("per_page", 100)
+
+        time_entries = []
+
+        # Skip pagination by looping over each page and adding tickets if 'page' key is not in kwargs.
+        # else return the requested page and break the loop
+        while True:
+            this_page = self._api._get(url + 'page={}&per_page={}'.format(page, per_page), kwargs)
+            time_entries += this_page
+            if len(this_page) < per_page or "page" in kwargs:
+                break
+
+            page += 1
+
+        return [TimeEntry(**c) for c in time_entries]
 
 
 class TicketFieldAPI(object):
@@ -528,6 +541,148 @@ class AgentAPI(object):
         return Agent(**self._api._get(url))
 
 
+class SolutionCategoryAPI(object):
+    def __init__(self, api):
+        self._api = api
+
+    def list_categories(self):
+        url = "solutions/categories"
+        categories = self._api._get(url)
+        return [SolutionCategory(**r) for r in categories]
+
+    def get_category(self, category_id):
+        url = "solutions/categories/%d" % category_id
+        return SolutionCategory(**self._api._get(url))
+    
+    def create_category(self, *args, **kwargs):
+        url = "solutions/categories"
+        return SolutionCategory(**self._api._post(url, data=json.dumps(kwargs)))
+    
+    def create_category_translation(self, category_id, lang_code, *args, **kwargs):
+        url = "solutions/categories/%d/%s" %(category_id, lang_code)
+        return SolutionCategory(**self._api._post(url, data=json.dumps(kwargs)))
+    
+    def update_category(self, category_id, *args, **kwargs):
+        url = "solutions/categories/%d" % category_id
+        return SolutionCategory(**self._api._put(url, data=json.dumps(kwargs)))
+    
+    def update_category_translation(self, category_id, lang_code, *args, **kwargs):
+        url = "solutions/categories/%d/%s" %(category_id, lang_code)
+        return SolutionCategory(**self._api._put(url, data=json.dumps(kwargs)))
+    
+    def delete_category(self, category_id):
+        url = 'solutions/categories/%s' % category_id
+        self._api._delete(url)
+
+    def get_category_translated(self, category_id, lang_code):
+        url = "solutions/categories/%d/%s" % (category_id,lang_code)
+        return SolutionCategory(**self._api._get(url))
+
+
+class SolutionFolderAPI(object):
+    def __init__(self, api):
+        self._api = api
+
+    def list_from_category(self, category_id):
+        url = "solutions/categories/%d/folders" % category_id
+        folders = self._api._get(url)
+        return [SolutionFolder(**r) for r in folders]
+
+    def list_from_category_translated(self, category_id, lang_code):
+        url = "solutions/categories/%d/folders/%s" % (category_id, lang_code)
+        folders = self._api._get(url)
+        return [SolutionFolder(**r) for r in folders]
+
+    def get_folder(self, folder_id):
+        url = "solutions/folders/%d" % folder_id
+        return SolutionFolder(**self._api._get(url))
+
+    def get_folder_translated(self, folder_id, lang_code):
+        url = "solutions/folders/%d/%s" % (folder_id, lang_code)
+        return SolutionFolder(**self._api._get(url))
+    
+    def create_folder(self, category_id, *args, **kwargs):
+        url = "solutions/categories/%s/folders" % category_id
+        return SolutionFolder(**self._api._post(url, data=json.dumps(kwargs)))
+    
+    def create_folder_translation(self, folder_id, lang_code, *args, **kwargs):
+        url = "solutions/folders/%s/%s" % ( folder_id, lang_code)
+        return SolutionFolder(**self._api._post(url, data=json.dumps(kwargs)))
+    
+    def update_folder(self, folder_id, *args, **kwargs):
+        url = "solutions/folders/%s" % (folder_id)
+        data = {}
+        data.update(kwargs)
+        return SolutionFolder(**self._api._put(url, data=json.dumps(data)))
+    
+    def update_folder_translation(self, folder_id, lang_code, *args, **kwargs):
+        url = "solutions/folders/%s/%s" % (folder_id, lang_code)
+        print(url)
+        data = {}
+        data.update(kwargs)
+        return SolutionFolder(**self._api._put(url, data=json.dumps(data)))
+    
+    def delete_folder(self, folder_id):
+        url = "solutions/folders/%s" % (folder_id)
+        self._api._delete(url)
+
+
+class SolutionArticleAPI(object):
+    def __init__(self, api):
+        self._api = api
+
+    def get_article(self, article_id):
+        url = "solutions/articles/%d" % article_id
+        return SolutionArticle(**self._api._get(url))
+
+    def get_article_translated(self, article_id, language_code):
+        url = "solutions/articles/%d/%s" % (article_id,language_code)
+        return SolutionArticle(**self._api._get(url))
+
+    def list_from_folder(self, id):
+        url = "solutions/folders/%d/articles" % id
+        articles = self._api._get(url)
+        return [SolutionArticle(**a) for a in articles]
+
+    def list_from_folder_translated(self, id, language_code):
+        url = "solutions/folders/%d/articles/%s" % (id, language_code)
+        articles = self._api._get(url)
+        return [SolutionArticle(**a) for a in articles]
+    
+    def create_article(self, folder_id, *args, **kwargs):
+        url = 'solutions/folders/%s/articles' % folder_id
+        return SolutionArticle(**self._api._post(url, data=json.dumps(kwargs)))
+
+    def create_article_translation(self, article_id, lang, *args, **kwargs):
+        url = 'solutions/articles/%s/%s' %( article_id, lang )
+        return SolutionArticle(**self._api._post(url, data=json.dumps(kwargs)))
+
+    def update_article(self, article_id, *args, **kwargs):
+        url = 'solutions/articles/%s' % article_id
+        return SolutionArticle(**self._api._put(url, data=json.dumps(kwargs)))
+
+    def update_article_translation(self, article_id, lang, *args, **kwargs):
+        url = 'solutions/articles/%s/%s' % ( article_id, lang )
+        return SolutionArticle(**self._api._put(url, data=json.dumps(kwargs)))
+
+    def delete_article(self, article_id):
+        url = 'solutions/articles/%s' % article_id
+        self._api._delete(url)
+
+    def search(self, keyword):
+        url = 'search/solutions?term=%s' % keyword
+        articles = []
+        for r in self._api._get(url):
+            articles.append(SolutionArticle(**r))
+        return articles
+
+class SolutionAPI(object):
+    def __init__(self, api):
+      self._api = api
+      self.categories = SolutionCategoryAPI(api)
+      self.folders = SolutionFolderAPI(api)
+      self.articles = SolutionArticleAPI(api)
+
 class API(object):
     def __init__(self, domain, api_key, verify=True, proxies=None):
         """Creates a wrapper to perform API actions.
@@ -556,6 +711,8 @@ class API(object):
         self.agents = AgentAPI(self)
         self.roles = RoleAPI(self)
         self.ticket_fields = TicketFieldAPI(self)
+        self.time_entries = TimeEntryAPI(self)
+        self.solutions = SolutionAPI(self)
 
         if domain.find("freshdesk.com") < 0:
             raise AttributeError("Freshdesk v2 API works only via Freshdesk" "domains and not via custom CNAMEs")
@@ -615,4 +772,5 @@ class API(object):
     def _delete(self, url):
         """Wrapper around request.delete() to use the API prefix. Returns a JSON response."""
         req = self._session.delete(self._api_prefix + url)
+        print(req)
         return self._action(req)
