@@ -99,10 +99,10 @@ class Contact(FreshdeskModel):
 
 class TimeEntry(FreshdeskModel):
     def __str__(self):
-        return str(self.id)
+        return "{} ({})".format(self.note, self.time_spent)
 
     def __repr__(self):
-        return "<Timesheet Entry {}>".format(self.id)
+        return "<Timesheet entry for Ticket #{}>".format(self.ticket_id)
 
 
 class Customer(FreshdeskModel):
@@ -135,3 +135,34 @@ class Role(FreshdeskModel):
 
     def __repr__(self):
         return "<Role '{}'>".format(self.name)
+
+
+class SolutionCategory(FreshdeskModel):
+    def __str__(self):
+        return self.name
+
+    def __repr__(self):
+        return "<SolutionCategory '{}' #{}>".format(self.name, self.id)
+
+
+class SolutionFolder(FreshdeskModel):
+    def __str__(self):
+       return self.name
+
+    def __repr__(self):
+       return "<SolutionFolder '{}' #{}>".format(self.name, self.id)
+
+
+class SolutionArticle(FreshdeskModel):
+    def __str__(self):
+        return self.title
+
+    def __repr__(self):
+        return "<SolutionArticle '{}' #{}>".format(self.title, self.id)
+
+    @property
+    def status(self):
+        _p = {1: "draft", 2: "published"}
+        return _p[self._status]
+
+
